==> enterprisemodules-ora_config-3.17.2.tar.gz: enterprisemodules-ora_config-3.17.2/README.md <==

[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

1. [Overview](#overview)
2. [Experience the Power of Puppet for Oracle databases](#experience-the-power-of-puppet-for-oracle-databases)
3. [License](#license)
4. [Description - What the module does and why it is useful](#description)
5. [Setup](#setup)
  * [Requirements](#requirements)
  * [Installing the ora_config module](#installing-the-ora_config-module)
6. [Usage - Configuration options and additional functionality](#usage)
7. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
8. [Limitations - OS compatibility, etc.](#limitations)

## Overview

This module allows you to configure and manage Oracle databases and Oracle ASM instances. It is part of our family of Puppet modules to install, manage and secure Oracle databases with Puppet. Besides the [`ora_config`](https://www.enterprisemodules.com/shop/products/puppet-ora_config-module?taxon_id=14) module, this family also contains:

- [ora_install](https://www.enterprisemodules.com/shop/products/puppet-ora_install-module?taxon_id=14) For installing an Oracle database and other database related Oracle products
- [ora_cis](https://www.enterprisemodules.com/shop/products/puppet-oracle-security-module?taxon_id=14) To secure your databases according to the CIS benchmarks.
- [ora_profile](https://forge.puppet.com/enterprisemodules/ora_profile) The ora_profile module allows an easy path from first simple installation to a fully customized Enterprise setup. 

All of these modules support Oracle versions 11, 12, 18 and 19.

## Experience the Power of Puppet for Oracle databases

Managing the configuration of your Oracle databases can be hard. With Puppet at your side, you get super-powers when installing and managing Oracle Databases. If you want to play and experiment with this [please take a look at our playgrounds](https://www.enterprisemodules.com/playgrounds#oracle). 

[![Experience the Power](https://raw.githubusercontent.com/enterprisemodules/public_images/master/superpowers-33-blanc.jpg)](https://www.enterprisemodules.com/playgrounds#oracle)


## Experience the Power of Puppet for IBM MQ

Installing IBM MQ software and managing your IBM MQ configuration can be hard. With Puppet at your side, you get super-powers when installing and managing IBM MQ. If you want to play and experiment with this [please take a look at our playgrounds](https://www.enterprisemodules.com/playgrounds#mq). 

[![Experience the Power](https://raw.githubusercontent.com/enterprisemodules/public_images/master/superpowers-33-blanc.jpg)](https://www.enterprisemodules.com/playgrounds#mq)


## License

This is a commercially licensed module. But you can use the module on VirtualBox based development systems for **FREE**. You can [request a **FREE** trial license here](https://www.enterprisemodules.com/sign-up-for-free-trial)

[![FREE TRIAL](https://raw.githubusercontent.com/enterprisemodules/public_images/master/free-trial.jpg)](https://www.enterprisemodules.com/sign-up-for-free-trial)

Check the [License](https://forge.puppet.com/enterprisemodules/ora_config/license) for details.

## Description

This module allows you to manage everything there is to manage in an Oracle database. For example you can manage: users, tablespaces and schemas and much more. The module contains the following types:

- [`ora_asm_directory`](https://www.enterprisemodules.com/docs/ora_config/ora_asm_directory.html)
- [`ora_asm_diskgroup`](https://www.enterprisemodules.com/docs/ora_config/ora_asm_diskgroup.html)
- [`ora_asm_volume`](https://www.enterprisemodules.com/docs/ora_config/ora_asm_volume.html)
- [`ora_database`](https://www.enterprisemodules.com/docs/ora_config/ora_database.html)
- [`ora_directory`](https://www.enterprisemodules.com/docs/ora_config/ora_directory.html)
- [`ora_exec`](https://www.enterprisemodules.com/docs/ora_config/ora_exec.html)
- [`ora_init_param`](https://www.enterprisemodules.com/docs/ora_config/ora_init_param.html)
- [`ora_listener`](https://www.enterprisemodules.com/docs/ora_config/ora_listener.html)
- [`ora_object_audit`](https://www.enterprisemodules.com/docs/ora_config/ora_object_audit.html)
- [`ora_object_grant`](https://www.enterprisemodules.com/docs/ora_config/ora_object_grant.html)
- [`ora_package`](https://www.enterprisemodules.com/docs/ora_config/ora_package.html)
- [`ora_procedure`](https://www.enterprisemodules.com/docs/ora_config/ora_procedure.html)
- [`ora_profile`](https://www.enterprisemodules.com/docs/ora_config/ora_profile.html)
- [`ora_record`](https://www.enterprisemodules.com/docs/ora_config/ora_record.html)
- [`ora_role`](https://www.enterprisemodules.com/docs/ora_config/ora_role.html)
- [`ora_scheduler_job`](https://www.enterprisemodules.com/docs/ora_config/ora_scheduler_job.html)
- [`ora_schema_definition`](https://www.enterprisemodules.com/docs/ora_config/ora_schema_definition.html)
- [`ora_service`](https://www.enterprisemodules.com/docs/ora_config/ora_service.html)
- [`ora_setting`](https://www.enterprisemodules.com/docs/ora_config/ora_setting.html)
- [`ora_statement_audit`](https://www.enterprisemodules.com/docs/ora_config/ora_statement_audit.html)
- [`ora_synonym`](https://www.enterprisemodules.com/docs/ora_config/ora_synonym.html)
- [`ora_tablespace`](https://www.enterprisemodules.com/docs/ora_config/ora_tablespace.html)
- [`ora_thread`](https://www.enterprisemodules.com/docs/ora_config/ora_thread.html)
- [`ora_trigger`](https://www.enterprisemodules.com/docs/ora_config/ora_trigger.html)
- [`ora_user`](https://www.enterprisemodules.com/docs/ora_config/ora_user.html)

Check [here](https://www.enterprisemodules.com/docs/ora_config/description.html) to see the full documentation for this module.

## Setup


### Requirements

The [`ora_config`](https://www.enterprisemodules.com/shop/products/puppet-ora_config-module?taxon_id=14) module requires:

- Puppet module [`enterprisemodules-easy_type`](https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet version 3.0 or higher. Can be Puppet Enterprise or Puppet Open Source
- Oracle 11 higher
- A valid Oracle license
- A valid Enterprise Modules license for usage.
- Runs on most Linux systems.
- Runs on Solaris
- Runs on Windows systems

### Installing the ora_config module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/ora_config'               ,'3.7.x'
```

Then use the`r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-ora_config
```

## Usage

Building a total Oracle setup requires quite some work. To help you, we have built [some examples](https://github.com/enterprisemodules/simple_db_demo). The repo contains a demonstration of a simple database installation. 


## Reference

Here you can find some more information regarding this puppet module:

- [The `ora_config` documentation](https://www.enterprisemodules.com/docs/ora_config/description.html)

Here are a related blog posts:
- [How to ensure you only use Oracle features you paid for](https://www.enterprisemodules.com/blog/2017/09/how-to-ensure-you-only-use-oracle-features-you-paid-for/)
- [Oracle 12.2 support added to our Oracle modules](https://www.enterprisemodules.com/blog/2017/03/oracle12-2-support/)
- [Secure your Oracle Database](https://www.enterprisemodules.com/blog/2017/02/secure-your-oracle-database/)
- [Manage Oracle containers with Puppet](https://www.enterprisemodules.com/blog/2017/01/manage-oracle-containers-with-puppet/)
- [Manage your oracle users with Puppet](https://www.enterprisemodules.com/blog/2016/10/manage-oracle-users-with-puppet/)
- [Reaching into your Oracle Database with Puppet](https://www.enterprisemodules.com/blog/2015/12/reaching-into-your-oracle-database-with-puppet/)
- [Manage your Oracle database schemas with Puppet](https://www.enterprisemodules.com/blog/2015/12/manage-your-oracle-database-schemas-with-puppet/)
- [Managing your Oracle database size with Puppet](https://www.enterprisemodules.com/blog/2015/11/managing-your-oracle-database-size-with-puppet/)
- [Using Puppet to manage Oracle](https://www.enterprisemodules.com/blog/2014/02/using-puppet-to-manage-oracle/)


## Limitations

This module runs on Solaris, AIX, Windows and most Linux versions. It requires a puppet version higher than 4. Other configurations are no supported.

==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/README.md <==

[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

1. [Overview](#overview)
2. [Experience the Power of Puppet for Oracle databases](#experience-the-power-of-puppet-for-oracle-databases)
3. [License](#license)
4. [Description - What the module does and why it is useful](#description)
5. [Setup](#setup)
  * [Requirements](#requirements)
  * [Installing the ora_config module](#installing-the-ora_config-module)
6. [Usage - Configuration options and additional functionality](#usage)
7. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
8. [Limitations - OS compatibility, etc.](#limitations)

## Overview

This module allows you to configure and manage Oracle databases and Oracle ASM instances. It is part of our family of Puppet modules to install, manage and secure Oracle databases with Puppet. Besides the [`ora_config`](https://www.enterprisemodules.com/shop/products/puppet-ora_config-module?taxon_id=14) module, this family also contains:

- [ora_install](https://www.enterprisemodules.com/shop/products/puppet-ora_install-module?taxon_id=14) For installing an Oracle database and other database related Oracle products
- [ora_cis](https://www.enterprisemodules.com/shop/products/puppet-oracle-security-module?taxon_id=14) To secure your databases according to the CIS benchmarks.
- [ora_profile](https://forge.puppet.com/enterprisemodules/ora_profile) The ora_profile module allows an easy path from first simple installation to a fully customized Enterprise setup. 

All of these modules support Oracle versions 11, 12, 18, 19 and 21.

## Experience the Power of Puppet for Oracle databases

Managing the configuration of your Oracle databases can be hard. With Puppet at your side, you get super-powers when installing and managing Oracle Databases. If you want to play and experiment with this [please take a look at our playgrounds](https://www.enterprisemodules.com/playgrounds#oracle). 

[![Experience the Power](https://raw.githubusercontent.com/enterprisemodules/public_images/master/superpowers-33-blanc.jpg)](https://www.enterprisemodules.com/playgrounds#oracle)


## Experience the Power of Puppet for IBM MQ

Installing IBM MQ software and managing your IBM MQ configuration can be hard. With Puppet at your side, you get super-powers when installing and managing IBM MQ. If you want to play and experiment with this [please take a look at our playgrounds](https://www.enterprisemodules.com/playgrounds#mq). 

[![Experience the Power](https://raw.githubusercontent.com/enterprisemodules/public_images/master/superpowers-33-blanc.jpg)](https://www.enterprisemodules.com/playgrounds#mq)


## License

This is a commercially licensed module. But you can use the module on VirtualBox based development systems for **FREE**. You can [request a **FREE** trial license here](https://www.enterprisemodules.com/sign-up-for-free-trial)

[![FREE TRIAL](https://raw.githubusercontent.com/enterprisemodules/public_images/master/free-trial.jpg)](https://www.enterprisemodules.com/sign-up-for-free-trial)

Check the [License](https://forge.puppet.com/enterprisemodules/ora_config/license) for details.

## Description

This module allows you to manage everything there is to manage in an Oracle database. For example you can manage: users, tablespaces and schemas and much more. The module contains the following types:

- [`ora_asm_directory`](https://www.enterprisemodules.com/docs/ora_config/ora_asm_directory.html)
- [`ora_asm_diskgroup`](https://www.enterprisemodules.com/docs/ora_config/ora_asm_diskgroup.html)
- [`ora_asm_volume`](https://www.enterprisemodules.com/docs/ora_config/ora_asm_volume.html)
- [`ora_database`](https://www.enterprisemodules.com/docs/ora_config/ora_database.html)
- [`ora_directory`](https://www.enterprisemodules.com/docs/ora_config/ora_directory.html)
- [`ora_exec`](https://www.enterprisemodules.com/docs/ora_config/ora_exec.html)
- [`ora_init_param`](https://www.enterprisemodules.com/docs/ora_config/ora_init_param.html)
- [`ora_listener`](https://www.enterprisemodules.com/docs/ora_config/ora_listener.html)
- [`ora_object_audit`](https://www.enterprisemodules.com/docs/ora_config/ora_object_audit.html)
- [`ora_object_grant`](https://www.enterprisemodules.com/docs/ora_config/ora_object_grant.html)
- [`ora_package`](https://www.enterprisemodules.com/docs/ora_config/ora_package.html)
- [`ora_procedure`](https://www.enterprisemodules.com/docs/ora_config/ora_procedure.html)
- [`ora_profile`](https://www.enterprisemodules.com/docs/ora_config/ora_profile.html)
- [`ora_record`](https://www.enterprisemodules.com/docs/ora_config/ora_record.html)
- [`ora_role`](https://www.enterprisemodules.com/docs/ora_config/ora_role.html)
- [`ora_scheduler_job`](https://www.enterprisemodules.com/docs/ora_config/ora_scheduler_job.html)
- [`ora_schema_definition`](https://www.enterprisemodules.com/docs/ora_config/ora_schema_definition.html)
- [`ora_service`](https://www.enterprisemodules.com/docs/ora_config/ora_service.html)
- [`ora_setting`](https://www.enterprisemodules.com/docs/ora_config/ora_setting.html)
- [`ora_statement_audit`](https://www.enterprisemodules.com/docs/ora_config/ora_statement_audit.html)
- [`ora_synonym`](https://www.enterprisemodules.com/docs/ora_config/ora_synonym.html)
- [`ora_tablespace`](https://www.enterprisemodules.com/docs/ora_config/ora_tablespace.html)
- [`ora_thread`](https://www.enterprisemodules.com/docs/ora_config/ora_thread.html)
- [`ora_trigger`](https://www.enterprisemodules.com/docs/ora_config/ora_trigger.html)
- [`ora_user`](https://www.enterprisemodules.com/docs/ora_config/ora_user.html)

Check [here](https://www.enterprisemodules.com/docs/ora_config/description.html) to see the full documentation for this module.

## Setup


### Requirements

The [`ora_config`](https://www.enterprisemodules.com/shop/products/puppet-ora_config-module?taxon_id=14) module requires:

- Puppet module [`enterprisemodules-easy_type`](https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet version 3.0 or higher. Can be Puppet Enterprise or Puppet Open Source
- Oracle 11 higher
- A valid Oracle license
- A valid Enterprise Modules license for usage.
- Runs on most Linux systems.
- Runs on Solaris
- Runs on Windows systems

### Installing the ora_config module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/ora_config'               ,'3.7.x'
```

Then use the`r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-ora_config
```

## Usage

Building a total Oracle setup requires quite some work. To help you, we have built [some examples](https://github.com/enterprisemodules/simple_db_demo). The repo contains a demonstration of a simple database installation. 


## Reference

Here you can find some more information regarding this puppet module:

- [The `ora_config` documentation](https://www.enterprisemodules.com/docs/ora_config/description.html)

Here are a related blog posts:
- [How to ensure you only use Oracle features you paid for](https://www.enterprisemodules.com/blog/2017/09/how-to-ensure-you-only-use-oracle-features-you-paid-for/)
- [Oracle 12.2 support added to our Oracle modules](https://www.enterprisemodules.com/blog/2017/03/oracle12-2-support/)
- [Secure your Oracle Database](https://www.enterprisemodules.com/blog/2017/02/secure-your-oracle-database/)
- [Manage Oracle containers with Puppet](https://www.enterprisemodules.com/blog/2017/01/manage-oracle-containers-with-puppet/)
- [Manage your oracle users with Puppet](https://www.enterprisemodules.com/blog/2016/10/manage-oracle-users-with-puppet/)
- [Reaching into your Oracle Database with Puppet](https://www.enterprisemodules.com/blog/2015/12/reaching-into-your-oracle-database-with-puppet/)
- [Manage your Oracle database schemas with Puppet](https://www.enterprisemodules.com/blog/2015/12/manage-your-oracle-database-schemas-with-puppet/)
- [Managing your Oracle database size with Puppet](https://www.enterprisemodules.com/blog/2015/11/managing-your-oracle-database-size-with-puppet/)
- [Using Puppet to manage Oracle](https://www.enterprisemodules.com/blog/2014/02/using-puppet-to-manage-oracle/)


## Limitations

This module runs on Solaris, AIX, Windows and most Linux versions. It requires a puppet version higher than 4. Other configurations are no supported.
